@@ -6,6 +6,7 @@ use warnings;
 use OpenResty::Util;
 use Params::Util qw( _HASH _STRING );
 use OpenResty::Limits;
+use OpenResty::RestyScript::View;
 
 sub POST_view {
     my ($self, $openresty, $bits) = @_;
@@ -101,8 +102,8 @@ sub PUT_view {
 }
 
 sub exec_view {
-    my ($self, $openresty,$view, $bits, $cgi) = @_;
-    my $select = OpenResty::MiniSQL::Select->new;
+    my ($self, $openresty, $view, $bits, $cgi) = @_;
+    my $select = OpenResty::RestyScript::View->new;
     my $sql = "select definition from _views where name = " . Q($view);
     ### laser exec_view: "$sql"
     my $view_def = $openresty->select($sql)->[0][0];
@@ -164,6 +165,9 @@ sub new_view {
     my $name = delete $data->{name} or
         die "No 'name' specified.\n";
     _IDENT($name) or die "Bad view name: ", $OpenResty::Dumper->($name), "\n";
+    if ($openresty->has_view($name)) {
+        die "View \"$name\" already exists.\n";
+    }
 
     my $minisql = delete $data->{definition};
     if (!defined $minisql) {
@@ -180,7 +184,7 @@ sub new_view {
         die "Unknown keys: ", join(" ", keys %$data), "\n";
     }
 
-    my $select = OpenResty::MiniSQL::Select->new;
+    my $select = OpenResty::RestyScript::View->new;
     eval {
         $res = $select->parse(
             $minisql,
